use crate::model::line_range::LineRange;

use super::*;

pub type Duplicates = Vec<Duplicate>;

#[derive(serde::Serialize, PartialOrd, PartialEq, Ord, Eq)]
pub struct Duplicate {
    pub file_1: Filename,
    pub file_1_line_range: LineRange,
    pub file_2: Filename,
    pub file_2_line_range: LineRange,
}
